@@ -14,10 +14,9 @@ use Exporter;
 # Load the neccessary Perl modules.
 use bytes;
 use Try::Catch;
-use Time::HiRes qw(ualarm);
 
 # Set the package version. 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -60,6 +59,10 @@ my $is_eval;
 
 # BEGIN block.
 BEGIN {
+    # Try to load Time::HiRes
+    eval {require Time::HiRes}
+    or die "Could not load module Time::HiRes\n";
+    import Time::HiRes qw(ualarm);
     # Try to load sys/ioctl.ph.
     $is_eval = ((eval "require 'sys/ioctl1.ph'") ? 1 : 0);
     if ($is_eval ne 1) {
@@ -85,8 +88,12 @@ BEGIN {
 # Clear the terminal window using escape sequences.                            #
 #------------------------------------------------------------------------------# 
 sub clear_screen {
+    # Set command sequences for clear and home.
+    my $clear = "2J";
+    my $home = "1;1H";
     # Clear screen.
-    my $escseq = "${CSI}2J${CSI}1;1H";
+    #my $escseq = "${CSI}2J${CSI}1;1H";
+    my $escseq = "${CSI}${clear}${CSI}${home}";
     # Get length of the escape sequence.
     my $buflen = length($escseq);
     # Write escape sequence to STDOUT.
@@ -458,10 +465,10 @@ Terminal::Control - Perl extension for the terminal window control
   my ($y, $x) = get_cursor_position();
   printf ("%s\n%s\n", $y, $x);
 
-  # Set the cursor position using escape sequences.
-  my $y = 20; 
-  my $x = 80; 
-  set_cursor_position($y, $x);
+  # Set the cursor position in chars not in pixels using escape sequences.
+  my $rows = 20; 
+  my $cols = 80; 
+  set_cursor_position($rows, $cols); # $rows and $cols must be set by the user
 
   # Enable echo of commands using stty. 
   echo_on();
@@ -478,10 +485,50 @@ Terminal::Control - Perl extension for the terminal window control
   # Set timeout in microseconds.
   my $timeout = 1000000;
   # Get window and screen size using escape sequences.
-  window_size_chars($timeout);
-  windows_size_pixels($timeout);
-  screen_size_chars($timeout);
-  screen_size_pixels($timeout);
+  window_size_chars($timeout);   # $timeout is optional. if not set 1000000 microseconds (1 second) is used.
+  windows_size_pixels($timeout); # $timeout is optional. if not set 1000000 microseconds (1 second) is used 
+  screen_size_chars($timeout);   # $timeout is optional. if not set 1000000 microseconds (1 second) is used 
+  screen_size_pixels($timeout);  # $timeout is optional. if not set 1000000 microseconds (1 second) is used 
+
+=head1 Motivation for Development
+
+The idea for the necessity of the module arises from the fact that especially 
+the call of the Perl command system C<system("reset")> of the Shell command
+C<reset> is noticeably slow.
+
+By using so-called ANSI escape sequences instead of calling a Shell command a
+significant acceleration can be achieved. The logical consequence is the
+programming of a Perl command that replaces the call of the Perl command system
+to reset the terminal window.
+
+A single method is the best way to realise this for the terminal reset and
+several other commands. There is no need to implement a class with a bunch of
+methods to achive this.  
+
+=head1 Prove of Concept
+
+Exemplary comparison of time of execution:
+
+  system("reset")  =>  1.026892 Seconds = 1026,892 Milliseconds = 1026892 Microseconds
+  
+  reset_screen()   =>  0.000076 Seconds =    0,076 Milliseconds = 76 Microseconds
+
+Using C<reset> on the command line and the Perl command C<system("reset")> have nearly
+the same result. Detailed comparison is outstanding. This one example already shows a
+significant advantage of the new routine.
+
+=head1 System Compatibility
+
+Three things must be fulfilled in order to use the full functionality of the
+module.
+
+On operating systems that support ANSI escape sequences, individual
+methods will work out of the box. Some methods use the Shell command stty.
+The Shell command stty must be available accordingly. One method is using the
+system call ioctl, which is optional with respect to the functionality of the
+module. The restriction under Perl is explained further below.
+
+The above requirements are fulfilled in principle by all Unix or Unix-like systems. 
 
 =head1 Requirement for Full Functionality
 
@@ -496,36 +543,18 @@ to create a C<sys/ioctl.ph>. This is necessary manually via the C<h2ph> command.
 To prevent tests within CPAN from failing due to a missing C<sys/ioctl.ph>, a
 fallback solution based on the Shell command C<stty> is implemented.   
 
-=head1 Introduction
+=head1 ANSI escape sequences versus XTERM control sequences
 
-The module can be used on Unix-like systems. 
-
-=head1 Motivation
-
-The idea for the necessity of the module arises from the fact that especially 
-the Perl system command call C<system("reset")> of the Shell command C<reset>
-is noticeably slow. The Shell command C<reset> is slow, the Perl system command
-call C<system("reset")> is slower. By using so-called ASCII escape sequences,
-a significant acceleration can be achieved. The logical consequence is the
-programming of a Perl command that replaces the Perl system command call. A
-simple method is the best way to realise this. There is no need to implement a
-special class to achive this.  
-
-=head1 Benchmark
-
-Exemplary comparison comparison of time of execution:
-
-system("reset")  =>  1.026892 Seconds = 1026,892 Milliseconds = 1026892 Microseconds
-  
-reset_screen()   =>  0.000076 Seconds =    0,076 Milliseconds = 76 Microseconds
-
-This one example already shows a significant advantage of the new routine.
+ANSI escape sequences are widely known. Less well known are the so-called XTERM
+control sequences.
 
 =head1 DESCRIPTION
 
 =head2 Implemented Methods
 
-The following methods have been implemented so far:
+The methods below are sorted according to their logical relationship.
+
+The following methods have been implemented so far within the module:
 
 =over 4 
 
@@ -533,24 +562,44 @@ The following methods have been implemented so far:
 
 =item * reset_screen()
 
+=back
+
+=over 4 
+
 =item * get_cursor_position()
 
 =item * set_cursor_position($rows, $cols)
 
+=back
+
+=over 4 
+
 =item * winsize()
 
 =item * chars()
 
 =item * pixels()
 
+=back
+
+=over 4 
+
 =item * echo_on()
 
 =item * echo_off()
 
+=back
+
+=over 4 
+
 =item * cursor_on()
 
 =item * cursor_off()
 
+=back
+
+=over 4 
+
 =item * screen_size_chars($timeout) 
 
 =item * screen_size_pixels($timeout)
@@ -561,6 +610,13 @@ The following methods have been implemented so far:
 
 =back
 
+Reading from STDIN is blocking, if no data are available. To overcome the
+problem of waiting endless for user input a timeout is programmed. Unfortunately,
+the programming implementation also slows down the processing when data is available
+in STDIN. If the standard value is not applicable, reduce the timeout step by step.
+If the timeout is to short the method is not able to catch the input from STDIN. A
+error code -1 is returned.
+
 =head1 Aliases
 
 clear_screen and reset_screen can also be used with this aliases:
@@ -573,33 +629,37 @@ clear_screen and reset_screen can also be used with this aliases:
 =head2 Method description
 
 The method C<clear_screen> is clearing the terminal. This is similar to the
-Perl system command call C<system('clear')>. The method C<reset_screen> is
+Perl system command call C<system("clear")>. The method C<reset_screen> is
 reseting the terminal. This is similar to the Perl system command call
-C<system('reset')>.
+C<system("reset")>.
 
-The method winsize gets the dimensions in x-direction and y-direction
+The method C<winsize()> gets the dimensions in x-direction and y-direction
 of the terminal. The methods chars and pixels extract chars (rows and cols)
- and pixels (xpix and ypix.)
+and pixels (xpix and ypix.)
 
 The method C<get_cursor_position()> gets the current cursor position in
 the terminal window. The method C<set_cursor_position()> sets the cursor
 position in the terminal window.
  
-C<echo_on()> and C<echo_off()> turnes echo of commands on or off. cursor_on and
-cursor_off shows or hides the cursor.
+C<echo_on()> and C<echo_off()> turnes echo of commands on or off.C<cursor_on()> and
+C<cursor_off> shows or hides the cursor.
 
 =head1 Programmable background
 
-The methods C<clear_screen()> and C<reset_screen()> are using escape sequences. Doing this
-no other Perl modules are needed to clear and reset a screen. Both are in principle
-one liners.
+The methods C<clear_screen()> and C<reset_screen()> are using ANSI escape sequences.
+Doing this no other Perl commands are needed to clear and reset a screen. 
 
-The method winsize is using the C/C++ header for the system C<ioctl> call and there
-the command C<TIOCGWINSZ>. The call return winsize in rows and cols and xpix and ypix.
+The method C<winsize()> is using the C/C++ header for the system call C<ioctl> and the
+call or command C<TIOCGWINSZ>. The call returns the winsize in rows and cols and xpix
+and ypix.
 
 =head1 SEE ALSO
 
-ASCII escape sequences
+ANSI escape sequences
+
+XTERM control sequences
+
+stty(1) - Linux manual page 
 
 =head1 AUTHOR
 
